iseven

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2023 License: GPL-2.0 Imports: 0 Imported by: 0

README

Is Even

A golang package to check is a number is even.

Installation

go get github.com/AvicennaJr/IsEven

How To Use

package main

import (
	"fmt"

	iseven "github.com/AvicennaJr/isEven"
)

func main() {
	n := 4
	if iseven.IsEven(n) {
		fmt.Println("It is even")
	} else {
		fmt.Println("It is not even")
	}
}

Issues

Do open issues for any complaints

Contributions

If you want to contribute, simply open a pull request.

Credits

Thanks to the hundreds of developers who made this project possible.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsEven

func IsEven(n int) bool

This function will check if a number is even. It will return true if true, or false if not.

Types

This section is empty.

Directories

Path Synopsis

Jump to